@@ -28,12 +28,12 @@
  * 	NOTES:
  *		- A?adir todos los kernels....
  *		- Mejorar la convoluci?n utiulizando simpson...
- *		- El selector del kernel deber?a basarse en RK(), as? la 
- *		funci?n en R pasa RK() y aqu? se compara con los diferentes 
+ *		- El selector del kernel deber?a basarse en RK(), as? la
+ *		funci?n en R pasa RK() y aqu? se compara con los diferentes
  *		RK() con una cierta tolerancia.
  * 	ERRORS:
  */
- 
+
 /*
  * Some kernels
  */
@@ -98,17 +98,17 @@ double CosK(double x)
 }
 
 /* Selector del kernel */
-typedef double (*funPtr)();
+typedef double (*funPtr)(double Ktype);
 
 funPtr selKernel(int Ktype)
 {
 	switch(Ktype)
 	{
-		case 1:	
+		case 1:
 			return( &EpaK );
-		case 2:	
+		case 2:
 			return( &Epa2K );
-		case 3:	
+		case 3:
 			return( &TrianK );
 		case 4:
 			return( &QuartK );
@@ -174,15 +174,15 @@ void parzenRossen(	double *xeval, int *neval,
 	n = number of data obs. length of 'x'.
 	bw = bandwidth.
 	Ktype = tipo de kernel:0=gaussK,1=EpaK,2=Epa2K,3=TrianK}
-	res = result vector. 
+	res = result vector.
 */
 {
 	int i,j;
 	funPtr kernel;
-	
+
 	/*	Selector de kernel */
 	kernel = selKernel(*Ktype);
-	
+
 	/*	operaci?n */
 	for(i=0;i<*neval;i++)
 	{
@@ -217,10 +217,10 @@ void simpleSmoother(double *xeval, int *neval,
 {
 	int i,j;
 	funPtr kernel;
-	
+
 	/*	Selector de kernel */
 	kernel = selKernel(*Ktype);
-	
+
 	/*	operaci?n */
 	for(i=0;i<*neval;i++)
 	{
@@ -240,16 +240,16 @@ void simpleSmoother(double *xeval, int *neval,
  void locWeightsEvalxx(double *lpweig, int *neval,
 					double *y, int*n, double *res)
 /*
-	lpweig = neval x n matrix 
+	lpweig = neval x n matrix
 	neval = number of  eval. points.
 	y = y data vector.
-	den = vector el denominador de cada estimaci?n. 
-	res = result matrix, len(xeval) x n dimension. 
+	den = vector el denominador de cada estimaci?n.
+	res = result matrix, len(xeval) x n dimension.
 */
 {
 	int i,j;
 	/*QUITAR:double wsum;*/
-	
+
 	/*	operaci?n */
 	for(i=0;i<*neval;i++)
 	{
@@ -273,17 +273,17 @@ void locCteSmoother(double *xeval, int *neval,
 	n = number of data obs. length of 'x' and 'y'.
 	bw = bandwidth.
 	Ktype = tipo de kernel:0=gaussK,1=EpaK,2=Epa2K,3=TrianK}
-	den = vector el denominador de cada estimaci?n. 
-	res = result vector. 
+	den = vector el denominador de cada estimaci?n.
+	res = result vector.
 */
 {
 	int i,j;
 	funPtr kernel;
 	double s0,t0;
-	
+
 	/*	Selector de kernel */
 	kernel = selKernel(*Ktype);
-	
+
 	/*	operaci?n */
 	for(i=0;i<*neval;i++)
 	{
@@ -296,7 +296,7 @@ void locCteSmoother(double *xeval, int *neval,
 		den[i] = s0;
 		if( fabs(s0)>TOLERANCE )
 			res[i] = t0/s0;
-		else 
+		else
 			res[i] = NA_VALUE;
 	}
 }
@@ -313,17 +313,17 @@ void locCteWeights(double *xeval, int *neval,
 	n = number of data obs. length of 'x' and 'y'.
 	bw = bandwidth.
 	Ktype = tipo de kernel:0=gaussK,1=EpaK,2=Epa2K,3=TrianK}
-	den = vector el denominador de cada estimaci?n. 
-	res = result matrix, len(xeval) x n dimension. 
+	den = vector el denominador de cada estimaci?n.
+	res = result matrix, len(xeval) x n dimension.
 */
 {
 	int i,j;
 	funPtr kernel;
 	double s0sum;
-	
+
 	/*	Selector de kernel */
 	kernel = selKernel(*Ktype);
-	
+
 	/*	operaci?n */
 	for(i=0;i<*neval;i++)
 	{
@@ -337,7 +337,7 @@ void locCteWeights(double *xeval, int *neval,
 		if( fabs(s0sum)>TOLERANCE )
 			for(j=0;j<*n;j++)
 				res[j*(*neval)+i] /= s0sum;
-		else 
+		else
 			for(j=0;j<*n;j++)
 				res[j*(*neval)+i] = NA_VALUE;
 	}
@@ -356,17 +356,17 @@ void locLinSmoother(double *xeval, int *neval,
  * 	n = number of data obs. length of 'x' and 'y'.
  * 	bw = bandwidth.
  * 	Ktype = tipo de kernel:0=gaussK,1=EpaK,2=Epa2K,3=TrianK}
- * 	den = vector el denominador de cada estimaci?n. 
+ * 	den = vector el denominador de cada estimaci?n.
  * 	res = result vector.
  */
 {
 	int i,j;
 	funPtr kernel;
 	double s0,s1,s2,t0,t1,auxK,aux;
-	
+
 	/*	Selector de kernel */
 	kernel = selKernel(*Ktype);
-	
+
 	/*	operaci?n */
 	for(i=0;i<*neval;i++)
 	{
@@ -388,7 +388,7 @@ void locLinSmoother(double *xeval, int *neval,
 			beta1[i] = -(s1*t0 - s0*t1)/den[i];
       beta1[i] /= (*bw);
 		}
-		else 
+		else
 			beta0[i] = beta1[i] = NA_VALUE;
 	}
 }
@@ -404,17 +404,17 @@ void locLinWeights(double *xeval, int *neval,
 	n = number of data obs. length of 'x' and 'y'.
 	bw = bandwidth.
 	Ktype = tipo de kernel:0=gaussK,1=EpaK,2=Epa2K,3=TrianK}
-	den = vector el denominador de cada estimaci?n. 
-	res = result matrix, len(xeval) x n dimension. 
+	den = vector el denominador de cada estimaci?n.
+	res = result matrix, len(xeval) x n dimension.
 */
 {
 	int i,j;
 	funPtr kernel;
 	double wsum,s1,s2,aux,auxK;
-	
+
 	/*	Selector de kernel */
 	kernel = selKernel(*Ktype);
-	
+
 	/*	operaci?n */
 	for(i=0;i<*neval;i++)
 	{
@@ -437,7 +437,7 @@ void locLinWeights(double *xeval, int *neval,
 		if( fabs(wsum)>TOLERANCE )
 			for(j=0;j<*n;j++)
 				res[j*(*neval)+i] /= wsum;
-		else 
+		else
 			for(j=0;j<*n;j++)
 				res[j*(*neval)+i] = NA_VALUE;
 	}
@@ -445,7 +445,7 @@ void locLinWeights(double *xeval, int *neval,
 
 void locCuadSmoother(double *xeval, int *neval,
 					double *x, double *y, double *weig, int*n, double *bw,
-					int *Ktype, double *den, 
+					int *Ktype, double *den,
 					double *beta0, double *beta1, double *beta2)
 /*
  * 	xeval = eval. points.
@@ -462,10 +462,10 @@ void locCuadSmoother(double *xeval, int *neval,
 	int i,j,k,l,deg;
 	funPtr kernel;
 	double s[MAXS],t[MAXT],aux,Kaux;
-	
+
 	/*	Selector de kernel */
 	kernel = selKernel(*Ktype);
-	
+
 	/*	operaci?n */
 	deg = 2;
 	for(i=0;i<*neval;i++)
@@ -492,19 +492,19 @@ void locCuadSmoother(double *xeval, int *neval,
 			for(l=k;l<=2*deg;l++)
 				s[l] += Kaux * R_pow_di(aux,l);
 		}
-		den[i] = R_pow_di(s[2],3) + s[0]*R_pow_di(s[3],2) + 
+		den[i] = R_pow_di(s[2],3) + s[0]*R_pow_di(s[3],2) +
 				 R_pow_di(s[1],2)*s[4] - s[2]*(2*s[1]*s[3] + s[0]*s[4]);
 		if( fabs(den[i]) > TOLERANCE )
 		{
 
-			beta0[i] = (R_pow_di(s[3],2)*t[0] - s[2]*s[4]*t[0] + s[1]*s[4]*t[1] + 
+			beta0[i] = (R_pow_di(s[3],2)*t[0] - s[2]*s[4]*t[0] + s[1]*s[4]*t[1] +
 				R_pow_di(s[2],2)*t[2] - s[3]*(s[2]*t[1] + s[1]*t[2])) / den[i];
-						
-			beta1[i] = (s[1]*s[4]*t[0] + R_pow_di(s[2],2)*t[1] - s[2]*(s[3]*t[0] + 
+
+			beta1[i] = (s[1]*s[4]*t[0] + R_pow_di(s[2],2)*t[1] - s[2]*(s[3]*t[0] +
 				s[1]*t[2]) + s[0]*(-(s[4]*t[1]) + s[3]*t[2])  ) / den[i] ;
 			beta1[i] /= (*bw);
-		
-			beta2[i] = (R_pow_di(s[2],2)*t[0] - s[1]*s[3]*t[0] + s[0]*s[3]*t[1] + 
+
+			beta2[i] = (R_pow_di(s[2],2)*t[0] - s[1]*s[3]*t[0] + s[0]*s[3]*t[1] +
 				R_pow_di(s[1],2)*t[2] - s[2]*(s[1]*t[1] + s[0]*t[2])) / den[i];
 			beta2[i] /= (*bw)*(*bw)/2;
 		}
@@ -519,30 +519,30 @@ void lsSolve(	double*a, int*lda, int*n, double*b, int*bcol,
 				double*rcond, double*z, int*info)
 /*
  *	a = symmetric matrix...
- *	lda = 
- *	n = 
- *	b = 
- *	bcol = 
- *	rcond = 
- *	z = 
- *	info = 
+ *	lda =
+ *	n =
+ *	b =
+ *	bcol =
+ *	rcond =
+ *	z =
+ *	info =
  */
 {
 	int j;
-	
+
 	dpoco_(a, lda, n, rcond, z, info);
 	if( fabs(*rcond)<TOLERANCE)
 		warning("Bad conditioned matrix.");
-	else if((*info)!=0) 
+	else if((*info)!=0)
 		warning("Bad info result.");
-	else	
+	else
 		for(j=0;j<(*bcol);j++)
 			dposl_(a,lda,n,&b[j*(*bcol)]);
 }
 
 
 void locPolSmoother(double *xeval, int *neval,
-					double *x, double *y, double *weig, int*n, 
+					double *x, double *y, double *weig, int*n,
 					double *bw, int *deg, int *Ktype, int *compDet,
 					double *den, double *beta)
 /*
@@ -562,10 +562,10 @@ void locPolSmoother(double *xeval, int *neval,
  *		Vaya foll?n......
  */
 {
-	int i, j, k, l, info, sncol, job; 
+	int i, j, k, l, info, sncol, job;
 	funPtr kernel;
 	double  s[MAXS], t[MAXT], z[MAXDEG], det[2], aux, Kaux, rcond;
-	
+
 	sncol = (*deg)+1;
 	//__TODO__ remove tncol = sncol;
 	/*	Selector de kernel */
@@ -592,7 +592,7 @@ void locPolSmoother(double *xeval, int *neval,
 					s[l*sncol+k] += Kaux * R_pow_di(aux,k+l);	/* s[k*sncol+l]=*/
 			}
 		}
-		/* Compute sol.  (det ?) */	
+		/* Compute sol.  (det ?) */
 		rcond=TOLERANCE+1;
 		info=0;
 		dpoco_(s, &sncol, &sncol, &rcond, z, &info);
@@ -614,7 +614,7 @@ void locPolSmoother(double *xeval, int *neval,
 		{
 			dposl_(s,  &sncol,  &sncol, t);
 			job = 10;
-			if( (*compDet) ) 
+			if( (*compDet) )
 			{
 				dpodi_(s,  &sncol,  &sncol, det, &job);
 				if( 1.0 <= det[0] && det[0] <= 10.0 )
@@ -627,10 +627,10 @@ void locPolSmoother(double *xeval, int *neval,
 			l = 1;
 			beta[i] = t[0];
 			for(k=1;k<=(*deg);k++)
-			{				
+			{
 				l *= k;
 				beta[k*(*neval)+i] = t[k]*l/aux;
-				aux *= (*bw);			
+				aux *= (*bw);
 			}
 		}
 	}
@@ -643,7 +643,7 @@ void locPolSmoother(double *xeval, int *neval,
  * Leave One out computations.
  * Estimation of m(x_i) i=1,...n without ith observation (x_i,y_i).
  */
-void looLocPolSmoother(	double *x, double *y, double *weig, int*n, 
+void looLocPolSmoother(	double *x, double *y, double *weig, int*n,
 						double *bw, int *deg, int *Ktype, int *compDet,
 						double *den, double *beta)
 /*
@@ -658,15 +658,15 @@ void looLocPolSmoother(	double *x, double *y, double *weig, int*n,
  *		El puto Fortran guarda las matrices por columnas!!!
  *		Vaya foll?n......
  *	RETURN
- *		Leave one out local polinomial estimator. It returns the estimation 
- *	of m(x_i) but without considering the i-th observation, in order to avoid 
+ *		Leave one out local polinomial estimator. It returns the estimation
+ *	of m(x_i) but without considering the i-th observation, in order to avoid
  *	possible biases.
  */
 {
-	int i, j, k, l, info, sncol, job;  //__TODO__ remove tncol, 
+	int i, j, k, l, info, sncol, job;  //__TODO__ remove tncol,
 	funPtr kernel;
 	double  s[MAXS], t[MAXT], z[MAXDEG], det[2], aux, Kaux, rcond;
-	
+
 	sncol = (*deg)+1;
 	//__TODO__ remove tncol = sncol;
 	/*	Selector de kernel */
@@ -696,7 +696,7 @@ void looLocPolSmoother(	double *x, double *y, double *weig, int*n,
 				}
 			}
 		}
-		/* Compute sol.  (det ?) */	
+		/* Compute sol.  (det ?) */
 		rcond=TOLERANCE+1;
 	  info=0;
 	  dpoco_(s, &sncol, &sncol, &rcond, z, &info);
@@ -718,7 +718,7 @@ void looLocPolSmoother(	double *x, double *y, double *weig, int*n,
 		{
 			dposl_(s,  &sncol,  &sncol, t);
 			job = 10;
-			if( (*compDet) ) 
+			if( (*compDet) )
 			{
 				dpodi_(s,  &sncol,  &sncol, det, &job);
 				if( 1.0 <= det[0] && det[0] <= 10.0 )
@@ -731,10 +731,10 @@ void looLocPolSmoother(	double *x, double *y, double *weig, int*n,
 			l = 1;
 			beta[i] = t[0];
 			for(k=1;k<=(*deg);k++)
-			{				
+			{
 				l *= k;
 				beta[k*(*n)+i] = t[k]*l/aux;
-				aux *= (*bw);			
+				aux *= (*bw);
 			}
 		}
 	}
@@ -746,12 +746,12 @@ void looLocPolSmoother(	double *x, double *y, double *weig, int*n,
  * 	cv.c
  * 		Funciones para Validaci?n Cruzada para el polinomio local en C.
  * 	NOTES:
- *		- Se proponen evaluadores, que se deben de llamar desde R y 
+ *		- Se proponen evaluadores, que se deben de llamar desde R y
  *		pasarselos a la funci?n 'optim()'.
  * 	ERRORS:
  */
 
-void denCVBwEval(	double *h,double *x, double *weig, int *n, 
+void denCVBwEval(	double *h,double *x, double *weig, int *n,
 					int *Ktype,double *res)
 /*
  * 	Compute CV evaluation for a given h.
@@ -759,7 +759,7 @@ void denCVBwEval(	double *h,double *x, double *weig, int *n,
  *	weig = weights.
  *	n = length of data points.
  *	Ktype = tipo de kernel:0=gaussK,1=EpaK,2=Epa2K,3=TrianK}
- *	res = result value. 
+ *	res = result value.
  *	NOTES:
  *		Cuidado con los pesos, no han de estar normalizados a n.
  */
@@ -767,10 +767,10 @@ void denCVBwEval(	double *h,double *x, double *weig, int *n,
 	funPtr kernel;
 	int i,j;
 	double aux,sumCuadWeig;
-	
+
 	/*	Selector de kernel */
 	kernel = selKernel(*Ktype);
-	
+
 	/*	Operation */
 	*res = 0.;
 	sumCuadWeig = 0.;
@@ -779,7 +779,7 @@ void denCVBwEval(	double *h,double *x, double *weig, int *n,
 		for(j=i+1;j<(*n);j++)
 		{
 			aux = (x[i]-x[j])/(*h);
-			*res += weig[i] * weig[j] * ( Kconvol(kernel,aux) - 
+			*res += weig[i] * weig[j] * ( Kconvol(kernel,aux) -
 					2 * (*n) * kernel(aux)/((*n)-1) );
 		}
 		sumCuadWeig += CUAD(weig[i]);
@@ -792,7 +792,7 @@ void denCVBwEval(	double *h,double *x, double *weig, int *n,
  * 		for(j=i+1;j<(*n);j++)
  * 		{
  * 			aux = (x[i]-x[j])/(*h);
- * 			*res += ( Kconvol(kernel,aux) - 
+ * 			*res += ( Kconvol(kernel,aux) -
  * 					2 * (*n) * kernel(aux)/((*n)-1) );
  * 		}
  * 	*res += (*n) * Kconvol(kernel,0.) / 2;
@@ -808,7 +808,7 @@ void swap(double *xx,double *yy)
 	*yy = aux;
 }
 
-void regCVBwEval(	double *h,double *x, double *y, double *weig, int *n, 
+void regCVBwEval(	double *h,double *x, double *y, double *weig, int *n,
 					int *deg, int *Ktype, double *res)
 /*
  * 	Compute CV evaluation for beta0 and a given h,.
@@ -817,14 +817,14 @@ void regCVBwEval(	double *h,double *x, double *y, double *weig, int *n,
  *	weig = weights.
  *	n = length of data points.
  *	Ktype = tipo de kernel:0=gaussK,1=EpaK,2=Epa2K,3=TrianK}
- *	res = result value. 
+ *	res = result value.
  *	NOTE:
  *		The behavior of 'weig' weigths has been not tested but considered.
  */
 {
 	int i, ult, neval,compDet;
 	double xeval,beta[MAXDEG],den[150];
-	
+
 	compDet = 0;	/* Should be zero, det is not needed  */
 	neval = 1;
 	ult = (*n)-1;
@@ -837,7 +837,7 @@ void regCVBwEval(	double *h,double *x, double *y, double *weig, int *n,
 		swap(&y[i],&y[ult]);
 		/* computo est. loc. */
 		xeval = x[ult];
-		locPolSmoother(	&xeval, &neval, x, y, weig, &ult, 
+		locPolSmoother(	&xeval, &neval, x, y, weig, &ult,
 						h, deg, Ktype, &compDet, den, beta);
 		/* Comp. ress */
 		*res += CUAD(y[ult] - beta[0]);
@@ -845,10 +845,10 @@ void regCVBwEval(	double *h,double *x, double *y, double *weig, int *n,
 		swap(&x[i],&x[ult]);
 		swap(&y[i],&y[ult]);
 	}
-	*res /= (*n); 
+	*res /= (*n);
 }
 
-void regCVBwEvalB(	double *h,double *x, double *y, double *weig, int *n, 
+void regCVBwEvalB(	double *h,double *x, double *y, double *weig, int *n,
 					int *deg, int *Ktype, double *res)
 /*
  * 	Compute CV evaluation for beta0 and a given h,.
@@ -857,14 +857,14 @@ void regCVBwEvalB(	double *h,double *x, double *y, double *weig, int *n,
  *	weig = weights.
  *	n = length of data points.
  *	Ktype = tipo de kernel:0=gaussK,1=EpaK,2=Epa2K,3=TrianK}
- *	res = result value. 
+ *	res = result value.
  *	NOTE:
  *		The behavior of 'weig' weigths has been not tested but considered.
  */
 {
 	int i,compDet;
 	double *beta, *den;
-	
+
 	compDet = 0;
 	den = (double *) R_alloc( (*n), sizeof(double) );
 	beta = (double *) R_alloc( ((*deg)+1)*(*n), sizeof(double) );
@@ -873,7 +873,7 @@ void regCVBwEvalB(	double *h,double *x, double *y, double *weig, int *n,
 	/* Operation */
 	for(i=0;i<(*n);i++)
 		*res += (CUAD(y[i] - beta[i]) * weig[i]);
-	*res /= (*n); 
+	*res /= (*n);
 }
 
 
@@ -894,18 +894,18 @@ void simpleSqSmoother(	double *xeval, int *neval,
  * 	n = number of data obs. length of 'x' and 'y'.
  * 	bw = bandwidth.
  * 	Ktype = tipo de kernel:0=gaussK,1=EpaK,2=Epa2K,3=TrianK}
- * 	res = result vector. 
+ * 	res = result vector.
  * 	RETURN
- * 		Simple Squared Smoother, computes a simple smoother but with a 
+ * 		Simple Squared Smoother, computes a simple smoother but with a
  * 	data and kernel squared.
  */
 {
 	int i,j;
 	funPtr kernel;
-	
+
 	/*	Selector de kernel */
 	kernel = selKernel(*Ktype);
-	
+
 	/*	operaci?n */
 	for(i=0;i<*neval;i++)
 	{
@@ -926,18 +926,18 @@ void locCteSqSmoother(	double *xeval, int *neval,
  * neval = number of  eval. points.
  * x = x data vector.
  * y = y data vector.
- * weig = vector of weigths for observations.	
+ * weig = vector of weigths for observations.
  * n = number of data obs. length of 'x' and 'y'.
  * bw = bandwidth.
  * Ktype = tipo de kernel:0=gaussK,1=EpaK,2=Epa2K,3=TrianK}
- * den = vector el denominador de cada estimaci?n. 
- * res = result vector. 
+ * den = vector el denominador de cada estimaci?n.
+ * res = result vector.
  *	NOTAS:
- *		Cuidado, lo que se ponga en y[i] se pondera por weig[i], con lo que 
+ *		Cuidado, lo que se ponga en y[i] se pondera por weig[i], con lo que
  *	en caso de datos sesgados no hay que poner los residuos ponderados, sino
  *	s?lo los residuos...
  *	RETURN
- *  	Simple Loc Constant Smoother, computes a simple smoother but with a 
+ *  	Simple Loc Constant Smoother, computes a simple smoother but with a
  *	data and kernel squared.
  *		It is an estimation of var of estimations of m(x),
  *	i.e.:'var(x)RK(kernel)\over f(x)'. */
@@ -945,10 +945,10 @@ void locCteSqSmoother(	double *xeval, int *neval,
 	int i,j;
 	funPtr kernel;
 	double s0;
-	
+
 	/*	Selector de kernel */
 	kernel = selKernel(*Ktype);
-	
+
 	/*	operaci?n */
 	for(i=0;i<*neval;i++)
 	{
@@ -979,14 +979,14 @@ void locLinSqSmoother(	double *xeval, int *neval,
  * 	n = number of data obs. length of 'x' and 'y'.
  * 	bw = bandwidth.
  * 	Ktype = tipo de kernel:0=gaussK,1=EpaK,2=Epa2K,3=TrianK}
- * 	den = vector el denominador de cada estimaci?n, sin elevar al cuadrado. 
+ * 	den = vector el denominador de cada estimaci?n, sin elevar al cuadrado.
  * 	res = result vector.
  *	NOTAS:
- *		Cuidado, lo que se ponga en y[i] se pondera por weig[i], con lo que 
+ *		Cuidado, lo que se ponga en y[i] se pondera por weig[i], con lo que
  *	en caso de datos sesgados no hay que poner los residuos ponderados, sino
  *	s?lo los residuos...
  *	RETURN
- *  	Simple Loc linear Smoother, computes a simple smoother but with a 
+ *  	Simple Loc linear Smoother, computes a simple smoother but with a
  * data and kernel squared.
  *		It is an estimation of var of estimations of m(x),
  *	i.e.:'var(x)RK(kernel)\over f(x)'.
@@ -998,7 +998,7 @@ void locLinSqSmoother(	double *xeval, int *neval,
 
 	/*	Selector de kernel */
 	kernel = selKernel(*Ktype);
-	
+
 	/* Operaci?n */
 	for(i=0;i<*neval;i++)
 	{
@@ -1018,12 +1018,12 @@ void locLinSqSmoother(	double *xeval, int *neval,
 		{
 			aux = (x[j]-xeval[i])/(*bw);
 			auxK = weig[j] * kernel( aux );
-			res[i] += CUAD( auxK * (s2-aux*s1) * y[j] ); 
+			res[i] += CUAD( auxK * (s2-aux*s1) * y[j] );
 		}
 		den[i] = (s2*s0 - s1*s1);
 		if( fabs(den[i])> TOLERANCE )
 			res[i] /= R_pow_di( den[i],2);/*R_pow( den[i],3./2.);*/
-		else 
+		else
 			res[i] = NA_VALUE;
 	}
 }
